==> jc-1.4.0.tar.gz: javax/swing/event/MenuDragMouseEvent.h <==
// public class javax.swing.event.MenuDragMouseEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 980152cfde7cf27b javax_swing_event_MenuDragMouseEvent

// header file dependencies
// @dep_header java_awt_event_MouseEvent

#include "java/awt/event/MouseEvent.h"

#ifndef _JC_javax_swing_event_MenuDragMouseEvent_H_
#define _JC_javax_swing_event_MenuDragMouseEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_MenuSelectionManager$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$sub_refs	_jc_javax_swing_event_MenuDragMouseEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs	_jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$refs	_jc_javax_swing_event_MenuDragMouseEvent$refs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$nonrefs	_jc_javax_swing_event_MenuDragMouseEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$object	_jc_javax_swing_event_MenuDragMouseEvent$object;

typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vmethods	_jc_javax_swing_event_MenuDragMouseEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vtable	_jc_javax_swing_event_MenuDragMouseEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vtype	_jc_javax_swing_event_MenuDragMouseEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuDragMouseEvent$method$_init$e38a6c525100bc7b(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *);

// Virtual methods
extern struct _jc_javax_swing_MenuSelectionManager$object *_jc_javax_swing_event_MenuDragMouseEvent$method$getMenuSelectionManager$aebcc6b5d8605322(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
extern _jc_object_array *_jc_javax_swing_event_MenuDragMouseEvent$method$getPath$1280a9aa069ec637(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
extern void _jc_javax_swing_event_MenuDragMouseEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$getMenuSelectionManager$aebcc6b5d8605322;
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$getPath$1280a9aa069ec637;
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_MenuDragMouseEvent$vmethods {
	struct _jc_javax_swing_MenuSelectionManager$object	*(*getMenuSelectionManager$aebcc6b5d8605322)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
	_jc_object_array	*(*getPath$1280a9aa069ec637)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_MenuDragMouseEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
	_jc_javax_swing_event_MenuDragMouseEvent$vmethods	javax_swing_event_MenuDragMouseEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuDragMouseEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuDragMouseEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuDragMouseEvent$sub_refs {
	_jc_object_array	*path;
	struct _jc_javax_swing_MenuSelectionManager$object	*manager;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuDragMouseEvent$refs {
    _jc_javax_swing_event_MenuDragMouseEvent$sub_refs	javax_swing_event_MenuDragMouseEvent;
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuDragMouseEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
    _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs	javax_swing_event_MenuDragMouseEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuDragMouseEvent$object {
	_jc_javax_swing_event_MenuDragMouseEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuDragMouseEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuDragMouseEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuDragMouseEvent$vtype _jc_javax_swing_event_MenuDragMouseEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuDragMouseEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuDragMouseEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuDragMouseEvent_H_ */

==> jc-1.4.5.tar.gz: javax/swing/event/MenuDragMouseEvent.h <==
// public class javax.swing.event.MenuDragMouseEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 980152cfde7cf27b javax_swing_event_MenuDragMouseEvent

// header file dependencies
// @dep_header java_awt_event_MouseEvent

#include "java/awt/event/MouseEvent.h"

#ifndef _JC_javax_swing_event_MenuDragMouseEvent_H_
#define _JC_javax_swing_event_MenuDragMouseEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_MenuSelectionManager$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$sub_refs	_jc_javax_swing_event_MenuDragMouseEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs	_jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$refs	_jc_javax_swing_event_MenuDragMouseEvent$refs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$nonrefs	_jc_javax_swing_event_MenuDragMouseEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuDragMouseEvent$object	_jc_javax_swing_event_MenuDragMouseEvent$object;

typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vmethods	_jc_javax_swing_event_MenuDragMouseEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vtable	_jc_javax_swing_event_MenuDragMouseEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuDragMouseEvent$vtype	_jc_javax_swing_event_MenuDragMouseEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuDragMouseEvent$method$_init$e38a6c525100bc7b(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_MenuSelectionManager$object *_jc_javax_swing_event_MenuDragMouseEvent$method$getMenuSelectionManager$aebcc6b5d8605322(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_event_MenuDragMouseEvent$method$getPath$1280a9aa069ec637(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_MenuDragMouseEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$getMenuSelectionManager$aebcc6b5d8605322;
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$getPath$1280a9aa069ec637;
extern _jc_method _jc_javax_swing_event_MenuDragMouseEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_MenuDragMouseEvent$vmethods {
	struct _jc_javax_swing_MenuSelectionManager$object	*(*getMenuSelectionManager$aebcc6b5d8605322)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPath$1280a9aa069ec637)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_MenuDragMouseEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
	_jc_javax_swing_event_MenuDragMouseEvent$vmethods	javax_swing_event_MenuDragMouseEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuDragMouseEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuDragMouseEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuDragMouseEvent$sub_refs {
	_jc_object_array	*path;
	struct _jc_javax_swing_MenuSelectionManager$object	*manager;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuDragMouseEvent$refs {
    _jc_javax_swing_event_MenuDragMouseEvent$sub_refs	javax_swing_event_MenuDragMouseEvent;
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuDragMouseEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
    _jc_javax_swing_event_MenuDragMouseEvent$sub_nonrefs	javax_swing_event_MenuDragMouseEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuDragMouseEvent$object {
	_jc_javax_swing_event_MenuDragMouseEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuDragMouseEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuDragMouseEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuDragMouseEvent$vtype _jc_javax_swing_event_MenuDragMouseEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuDragMouseEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuDragMouseEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuDragMouseEvent_H_ */
